ISignatureVerifierInstance

Struct ISignatureVerifierInstance 

pub struct ISignatureVerifierInstance<P, N = Ethereum> {
    address: Address,
    provider: P,
    _network: PhantomData<N>,
}
A ISignatureVerifier instance.

Contains type-safe methods for interacting with an on-chain instance of the ISignatureVerifier contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Fields

address: Addressprovider: P_network: PhantomData<N>

Implementations



impl<P, N> ISignatureVerifierInstance<P, N>
where P: Provider<N>, N: Network,

Instantiation and getters/setters.

pub const fn new( address: Address, __provider: P, ) -> ISignatureVerifierInstance<P, N>

Creates a new wrapper around an on-chain ISignatureVerifier contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> ISignatureVerifierInstance<P, N>

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.



impl<P, N> ISignatureVerifierInstance<&P, N>
where P: Clone,

pub fn with_cloned_provider(self) -> ISignatureVerifierInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.



impl<P, N> ISignatureVerifierInstance<P, N>
where P: Provider<N>, N: Network,

Function calls.

pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>
where C: SolCall,

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn recover( &self, hash: FixedBytes<32>, signature: Bytes, ) -> CallBuilder<&P, PhantomData<recoverCall>, N>

Creates a new call builder for the [recover] function.

pub fn verify( &self, signer: Address, hash: FixedBytes<32>, signature: Bytes, ) -> CallBuilder<&P, PhantomData<verifyCall>, N>

Creates a new call builder for the [verify] function.

pub fn verifyKeychain( &self, account: Address, hash: FixedBytes<32>, signature: Bytes, ) -> CallBuilder<&P, PhantomData<verifyKeychainCall>, N>

Creates a new call builder for the [verifyKeychain] function.

pub fn verifyKeychainAdmin( &self, account: Address, hash: FixedBytes<32>, signature: Bytes, ) -> CallBuilder<&P, PhantomData<verifyKeychainAdminCall>, N>

Creates a new call builder for the [verifyKeychainAdmin] function.



impl<P, N> ISignatureVerifierInstance<P, N>
where P: Provider<N>, N: Network,

Event filters.

pub fn event_filter<E>(&self) -> Event<&P, E, N>
where E: SolEvent,

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.